.. This Software (Dioptra) is being made available as a public service by the
.. National Institute of Standards and Technology (NIST), an Agency of the United
.. States Department of Commerce. This software was developed in part by employees of
.. NIST and in part by NIST contractors. Copyright in portions of this software that
.. were developed by NIST contractors has been licensed or assigned to NIST. Pursuant
.. to Title 17 United States Code Section 105, works of NIST employees are not
.. subject to copyright protection in the United States. However, NIST may hold
.. international copyright in software created by its employees and domestic
.. copyright (or licensing rights) in portions of software that were assigned or
.. licensed to NIST. To the extent that NIST holds copyright in this software, it is
.. being made available under the Creative Commons Attribution 4.0 International
.. license (CC BY 4.0). The disclaimers of the CC BY 4.0 license apply to all parts
.. of the software developed or licensed by NIST.
..
.. ACCESS THE FULL CC BY 4.0 LICENSE HERE:
.. https://creativecommons.org/licenses/by/4.0/legalcode

.. _global-glossary:

Glossary
========

.. glossary::

   API
      An acronym for the term *Application Programming Interface*, which refers to an interface that allows two applications to talk to one another.
      More recently, the term has been used as a shorthand for a *Web API*, see https://en.wikipedia.org/wiki/Web_API for further details.

   AML
      An acronym for the term *Adversarial Machine Learning*.

   CW
      An abbreviation for the Carlini-Wagner adversarial attack, which was first proposed in the conference paper titled "Towards Evaluating the Robustness of Neural Networks" by Nicholas Carlini and David Wagner.
      A copy of the paper is available on the arXiv at https://arxiv.org/abs/1608.04644.

   FGM
      An abbreviation for the Fast Gradient Method adversarial attack, which was first proposed in the conference paper title "Explaining and Harnessing Adversarial Examples" by Ian Goodfellow, Jonathan Shlens, and Christian Szegedy.
      A copy of the paper is available on the arXiv at https://arxiv.org/abs/1412.6572.

   HTTP
      An acronym for the term *Hypertext Transfer Protocol*, which are a set of rules that control the way data is sent and received over the internet.
      The HTTP specification is available at https://httpwg.org/specs/.

   JSMA
      An acronym for the term *Jacobian Saliency Map Attack*, a type of adversarial machine learning evasion attack that was first proposed in the paper titled "The Limitations of Deep Learning in Adversarial Settings" by Nicolas Papernot, Patrick McDaniel, Somesh Jha, Matt Fredrikson, Z. Berkay Celik, and Ananthram Swami.
      A copy of the paper is available on the arXiv at https://arxiv.org/abs/1511.07528.

   JSON
      An acronym for the term *JavaScript Object Notation*.
      JSON is a lightweight data-interchange format that is completely language independent despite being based on a subset of the JavaScript Programming Language Standard ECMA-262 3rd Edition - December 1999.
      For more information, see https://www.json.org.

   MNIST
      An acronym for the Modified National Institute of Standards and Technology database of handwritten digits.

   NVIDIA DGX
      A line of NVIDIA produced servers and workstations which specialize in using GPGPU to accelerate deep learning applications.
      For more information, see https://en.wikipedia.org/wiki/Nvidia_DGX.

   REST
      An acronym for REpresentational State Transfer, which is an architectural approach to designing web services `proposed by Roy Fielding in 2000 <https://www.ics.uci.edu/~fielding/pubs/dissertation/rest_arch_style.htm>`_.
      For more information, see https://docs.microsoft.com/en-us/azure/architecture/best-practices/api-design#what-is-rest.

   SDK
      An acronym for the term *Software Development Kit*, which refers to a collection of software development tools in one installable package.

   URI
      An acronym for the term *Uniform Resource Identifier*, which is a unique sequence of characters that identifies a logical or physical resource used by web technologies.
      For more information, see https://en.wikipedia.org/wiki/Uniform_Resource_Identifier.

   UUID
      An acronym for the term *Universally Unique IDentifier*, which is a 128-bit label used for information in computer systems.
      When generated according to the standard methods, UUIDs are, for practical purposes, unique.
      For more information, see https://en.wikipedia.org/wiki/Universally_unique_identifier.

   YAML
      An acronym for the term *YAML Ain't Markup Language*.
      YAML is a human friendly data serialization standard for all programming languages.
      For more information, see https://yaml.org.
